@@ -1,15 +1,15 @@
-# encoding: utf-8
+# frozen_string_literal: true
 
-RSpec.describe Pastel::Color, '#code' do
+RSpec.describe Pastel::Color, "#code" do
   let(:string) { "This is a \e[1m\e[34mbold blue text\e[0m" }
 
   subject(:color) { described_class.new(enabled: true) }
 
-  it 'finds single code' do
+  it "finds single code" do
     expect(color.code(:black)).to eq([30])
   end
 
-  it 'finds more than one code' do
+  it "finds more than one code" do
     expect(color.code(:black, :green)).to eq([30, 32])
   end
 
