@@ -7,4 +7,10 @@ RSpec.describe Pastel::Color, '::new' do
     expect(color.enabled?).to eq(false)
     expect(color.decorate("Unicorn", :red)).to eq("Unicorn")
   end
+
+  it "allows wrapping eachline in colors" do
+    color = described_class.new(eachline: "\n")
+
+    expect(color.eachline).to eq("\n")
+  end
 end
